inline FBB::lm::lm(int value)
:
    d_value(value < 0 ? 0 : value)
{}
